@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2016-03-13'; # DATE
-our $VERSION = '1.68'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '1.69'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -296,14 +296,14 @@ sub BUILD {
 }
 
 sub __json_decode {
-    require JSON;
-    state $json = do { JSON->new->allow_nonref };
+    require JSON::MaybeXS;
+    state $json = do { JSON::MaybeXS->new->allow_nonref };
     $json->decode(shift);
 }
 
 sub __json_encode {
-    require JSON;
-    state $json = do { JSON->new->allow_nonref };
+    require JSON::MaybeXS;
+    state $json = do { JSON::MaybeXS->new->allow_nonref };
     $json->encode(shift);
 }
 
@@ -783,7 +783,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.68 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2016-03-13.
+This document describes version 1.69 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
